powered by
icite_search returns the parsed results of a single call to the iCite API
icite_search
icite_search(year = NA, offset = NA, limit = NA)
character or numeric. The year whose data you would like
character. The minimum PMID you would like to have returned
character. The maximum number of records you would like returned. There is a maximum of 1000 for a single call.
If the call runs without error, the output is a simple S3 object
# NOT RUN { dat <- icite_search(year=2012, offset = 18008027, limit=10) print(dat) # }
Run the code above in your browser using DataLab