Learn R Programming

iCiteR (version 0.2.1)

search_metrics: Searches the icite database for entries that match the entered criteria

Description

search metrics takes a set of search criteria and returns a dataframe of the information yielded by the iCite API.

Usage

search_metrics(year = NA, offset = NA, limit = NA, page = FALSE)

Arguments

year

character or numeric. The year whose data you would like

offset

character. The minimum PMID you would like to have returned

limit

character. The maximum number of records you would like returned. There is a maximum of 1000 for a single call.

page

logical. Do you want to continue paging through the API until there is no new data returned (paging without a limit may take several hours to complete)?

Value

All values from the icite_api reformatted into a dataframe. See https://icite.od.nih.gov/api for details.

Examples

Run this code
# NOT RUN {
search_metrics(year=2012, offset='1800000', limit='2000', page=TRUE)
# }

Run the code above in your browser using DataLab